@@ -43,6 +43,13 @@ KEY__oauth_token = "oauth_token"
 KEY__accounts = "accounts"
 KEY__registered = "registered"
 KEY__restrictions = "restrictions"
+KEY__command = "command"
+
+CRON_minute = "minute"
+CRON_hour = "hour"
+CRON_dayOfMonth = "dayOfMonth"
+CRON_month = "month"
+CRON_dayOfWeek = "dayOfWeek"
 
 REGEX__dmbs_object_name = r'^[0-9a-zA-Z_]{1,32}$'
 
@@ -170,5 +177,5 @@ ROLE__postgres = "postgres"
 
 PROTOCOL__postgres = "postgresql://"
 
-VERSION = "4.22.4"
+VERSION = "4.22.6"
 
