@@ -190,9 +190,7 @@ class BaseJAAQLController:
                 for itm in data[arg.name]:
                     BaseJAAQLController.validate_data_rec(arg.arg_type.responses, itm, fill_missing)
             elif arg.name in data and arg.arg_type == ARG_RESP__allow_all:
-                if not isinstance(data[arg.name], dict):
-                    raise HttpStatusException(ERR__argument_wrong_type % (arg.name, type(data[arg.name]).__name__,
-                                                                          type(dict).__name__), HTTPStatus.BAD_REQUEST)
+                continue
             elif arg.name in data and not isinstance(data[arg.name], arg.arg_type):
                 if data[arg.name] is None and not arg.required:
                     continue
